==> spirit_hub-0.0.1.6.tar.gz: spirit_hub-0.0.1.6/e2e/cypress/e2e/features/views/to_classify.js <==
import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

// Right colums
Given('There is one tagset to classify with all columns', () => {
  cy.appFactories([['create', 'tagset_doc', 'with_informed', 'with_file', { responsible: '1', tagset_ids: [] }]]);
});

Then('I should see the right columns', () => {
  cy.get('#model_table td').eq(3).contains('Doc Title 1');
  cy.get('#model_table td').eq(4).contains('7.1 Ko');
  cy.get('#model_table td').eq(5).contains(new Date().toLocaleDateString('fr-FR'));
  cy.get('#model_table td').eq(6).find('div').should('exist');
  cy.get('#model_table td').eq(7).find('img').should('exist');
  cy.get('#model_table td').eq(8).contains('À classer');
  cy.get('#model_table td').eq(9).find('a').should('exist');
});

Given('There is some to_classify docs', () => {
  cy.appFactories([['create_list', 'tagset_doc', 5, { responsible: '1', tagset_ids: [] }]]);
});

Given('There is a lot of to_classify docs', () => {
  cy.appFactories([['create_list', 'tagset_doc', 20, { responsible: '1', tagset_ids: [] }]]);
});

Given('There is some docs and some directories', () => {
  cy.appFactories([['create_list', 'tagset_doc', 5, { responsible: '1', tagset_ids: [] }]]);

  cy.appFactories([['create', 'tagset_directory', { responsible: '1', title: 'Searchable tagset 1' }]]);
  cy.appFactories([['create', 'tagset_directory', { responsible: '1', title: 'Searchable tagset 2' }]]);
  cy.appFactories([['create_list', 'tagset_directory', 10, { responsible: '1' }]]);
});

// classify docs
When('I click on the classify button', () => {
  cy.get('#model_table tbody tr:first form[action="/spirit_hub/tagsets/form/classify"] button').click();
});

When('I search for a directory', () => {
  cy.get('input[data-classify-target="inputSearch"]').type('search');
  cy.get('label').contains('Searchable tagset 1').click();
});

When('I select the first directory', () => {
  cy.get('label').contains('Searchable tagset 1').click();
});

When('I validated the form', () => {
  cy.get('button[data-classify-target="submitButton"]').click();
});

Then("I shouldnt't see the first doc in the list", () => {
  cy.get('#model_table tbody tr').should('have.length', 5);
});

When('I click on the classify button in the grid view', () => {
  cy.get('.grid>div:first form[action="/spirit_hub/tagsets/form/classify"] button').click({ force: true });
});

Then("I shouldnt't see the first doc in the grid view", () => {
  cy.get('.grid>div').should('have.length', 3);
});

When('I select the first 3 docs and bulk classify them', () => {
  cy.get('#model_table tbody tr').eq(0).find('td:eq(1) input').check();
  cy.get('#model_table tbody tr').eq(1).find('td:eq(1) input').check();
  cy.get('#model_table tbody tr').eq(2).find('td:eq(1) input').check();

  cy.get('button[formaction="/spirit_hub/tagsets/form/classify"]').click();

  cy.get('label').contains('Tagset Title 9').click();
  cy.get('button[data-classify-target="submitButton"]').click();
});

Then("I shouldnt't see the first 3 doc in the list", () => {
  cy.get('#model_table tbody tr').should('have.length', 3);
});

// Add doc
Then('I should see the doc in the list', () => {
  cy.get('#model_table tbody tr:visible').should('have.length', 6);
});

==> spirit_hub-0.1.1.6.tar.gz: spirit_hub-0.1.1.6/e2e/cypress/e2e/features/views/to_classify.js <==
import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

// Right colums
Given('There is one tagset to classify with all columns', () => {
  cy.appFactories([['create', 'tagset_doc', 'with_informed', 'with_file', { responsible: '1', tagset_ids: [] }]]);
});

Then('I should see the right columns', () => {
  cy.get('#model_table td').eq(3).contains('Doc Title 1');
  cy.get('#model_table td').eq(4).contains('7.1 Ko');
  cy.get('#model_table td').eq(5).contains(new Date().toLocaleDateString('fr-FR'));
  cy.get('#model_table td').eq(6).find('div').should('exist');
  cy.get('#model_table td').eq(7).find('img').should('exist');
  cy.get('#model_table td').eq(8).contains('À classer');
  cy.get('#model_table td').eq(9).find('a').should('exist');
});

Given('There is some to_classify docs', () => {
  cy.appFactories([['create_list', 'tagset_doc', 5, { responsible: '1', tagset_ids: [] }]]);
});

Given('There is a lot of to_classify docs', () => {
  cy.appFactories([['create_list', 'tagset_doc', 20, { responsible: '1', tagset_ids: [] }]]);
});

Given('There is some docs and some directories', () => {
  cy.appFactories([['create_list', 'tagset_doc', 5, { responsible: '1', tagset_ids: [] }]]);

  cy.appFactories([['create', 'tagset_directory', { responsible: '1', title: 'Searchable tagset 1' }]]);
  cy.appFactories([['create', 'tagset_directory', { responsible: '1', title: 'Searchable tagset 2' }]]);
  cy.appFactories([['create_list', 'tagset_directory', 10, { responsible: '1' }]]);
});

// classify docs
When('I click on the classify button', () => {
  cy.get('#model_table tbody tr:first form[action="/spirit_hub/tagsets/form/classify"] button').click();
});

When('I search for a directory', () => {
  cy.get('input[data-classify-form-target="inputSearch"]').type('search');
  cy.get('label').contains('Searchable tagset 1').click();
});

When('I select the first directory', () => {
  cy.get('label').contains('Searchable tagset 1').click();
});

When('I validated the form', () => {
  cy.get('button[data-classify-form-target="submitButton"]').click();
});

Then("I shouldnt't see the first doc in the list", () => {
  cy.get('#model_table tbody tr').should('have.length', 5);
});

When('I click on the classify button in the grid view', () => {
  cy.get('.grid>div:first form[action="/spirit_hub/tagsets/form/classify"] button').click({ force: true });
});

Then("I shouldnt't see the first doc in the grid view", () => {
  cy.get('.grid>div').should('have.length', 3);
});

When('I select the first 3 docs and bulk classify them', () => {
  cy.get('#model_table tbody tr').eq(0).find('td:eq(1) input').check();
  cy.get('#model_table tbody tr').eq(1).find('td:eq(1) input').check();
  cy.get('#model_table tbody tr').eq(2).find('td:eq(1) input').check();

  cy.get('button[formaction="/spirit_hub/tagsets/form/classify"]').click();

  cy.get('label').contains('Tagset Title 9').click();
  cy.get('button[data-classify-form-target="submitButton"]').click();
});

Then("I shouldnt't see the first 3 doc in the list", () => {
  cy.get('#model_table tbody tr').should('have.length', 3);
});

// Add doc
Then('I should see the doc in the list', () => {
  cy.get('#model_table tbody tr:visible').should('have.length', 6);
});
